@@ -526,7 +526,6 @@ void OgreRenderEngine::LoadPlugins()
 //////////////////////////////////////////////////
 void OgreRenderEngine::CreateRenderSystem()
 {
-  Ogre::RenderSystem *renderSys;
   const Ogre::RenderSystemList *rsList;
 
   // Set parameters of render system (window size, etc.)
@@ -538,7 +537,7 @@ void OgreRenderEngine::CreateRenderSystem()
 
   int c = 0;
 
-  renderSys = nullptr;
+  Ogre::RenderSystem *renderSys = nullptr;
 
   do
   {
@@ -559,6 +558,7 @@ void OgreRenderEngine::CreateRenderSystem()
     gzerr << "unable to find OpenGL rendering system. OGRE is probably "
             "installed incorrectly. Double check the OGRE cmake output, "
             "and make sure OpenGL is enabled." << std::endl;
+    return;
   }
 
   // We operate in windowed mode
@@ -878,3 +878,5 @@ OgreRenderEngine *OgreRenderEngine::Instance()
 // Register this plugin
 GZ_ADD_PLUGIN(rendering::OgreRenderEnginePlugin,
               rendering::RenderEnginePlugin)
+GZ_ADD_PLUGIN_ALIAS(rendering::OgreRenderEnginePlugin,
+                    "gz::rendering::ogre::Plugin")
