@@ -143,3 +143,5 @@ OptixRenderEngine *OptixRenderEngine::Instance()
 // Register this plugin
 GZ_ADD_PLUGIN(OptixRenderEnginePlugin,
               rendering::RenderEnginePlugin)
+GZ_ADD_PLUGIN_ALIAS(OptixRenderEnginePlugin,
+                    "gz::rendering::optix::Plugin")
